import http from 'k6/http'
import { group, check, sleep } from 'k6'

import { spacesByMemberIdQuery } from './queries.js'
import { authenticatedUserQuery } from '../common/queries.js'
import { headers, websiteUrl } from '../const.js'
import { createPostRequest, checkResponse, isResponseValid } from '../utils.js'
import { checkFailureRate, timeToFirstByte } from '../main.js'

export function profile(data) {
  group('Profile', function () {
    const res = http.get(websiteUrl + '/profile', {
      headers,
    })

    const checkRes = check(res, {
      'is status 200': (r) => r.status === 200,
    })

    // Record check failures
    checkFailureRate.add(!checkRes)

    // Record time to first byte and tag it with the URL to be able to filter the results in Insights
    timeToFirstByte.add(res.timings.waiting, { ttfbURL: res.url })

    group('Authenticated user', function () {
      const resAuthenticatedUser = createPostRequest(
        authenticatedUserQuery,
        {
          userId: data.userId,
        },
        { name: 'AuthenticatedUserQuery' },
        data.graphQLAuthenticatedUserHeaders,
      )
      checkResponse(resAuthenticatedUser)
      sleep(0.1)

      if (isResponseValid(resAuthenticatedUser)) {
        const userId = JSON.parse(resAuthenticatedUser.body).data.authenticatedUser.id

        const resSpacesByMember = createPostRequest(
          spacesByMemberIdQuery,
          {
            memberId: userId,
          },
          { name: 'SpacesByMember' },
          data.graphQLAuthenticatedUserHeaders,
        )
        checkResponse(resSpacesByMember)
        sleep(0.1)
      }
    })
  })
}
